==> kadu_3.0.orig.tar.bz2: kadu-3.0/plugins/config_wizard/translations/config_wizard_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Kadu needs to be restarted before changes to the language settings will take effect.</source>
        <translation>Kadu debe reiniciarse antes para que los cambios en la configuración de idioma tengan efecto.</translation>
    </message>
</context>
<context>
    <name>ConfigWizardChooseNetworkPage</name>
    <message>
        <source>&lt;h3&gt;Account Setup&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Configuración de la Cuenta&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>IM Network</source>
        <translation>Red IM</translation>
    </message>
    <message>
        <source>I want to set up existing account for Kadu</source>
        <translation>Quiero configurar una cuenta existente para Kadu</translation>
    </message>
    <message>
        <source>I want to create new account for Kadu</source>
        <translation>Quiero crear nueva cuenta para Kadu</translation>
    </message>
    <message>
        <source>I don&apos;t want to set up my account for Kadu now</source>
        <translation>No quiero configurar mi cuenta para Kadu ahora</translation>
    </message>
    <message>
        <source>&lt;p&gt;Please choose the network for the account that you would like to set up.&lt;/p&gt;&lt;p&gt;You can also create a new account in the wizard if you don&apos;t already have one&lt;/p&gt;</source>
        <translation>&lt;p&gt;Por favor, elige la red para la cuenta que deseas configurar.&lt;/p&gt;&lt;p&gt;También puedes crear una cuenta nueva en el asistente si todavía no tienes una&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>ConfigWizardCompletedPage</name>
    <message>
        <source>&lt;h3&gt;Configuration Wizard Completed&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Asistente de Configuración Completado&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>Go to Accounts Setting after closing this window</source>
        <translation>Ir a la Configuración de las Cuentas después de cerrar esta ventana</translation>
    </message>
    <message>
        <source>&lt;p&gt;Confirm your wizard setting to start using Kadu.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Confirma tu configuración del asistente para empezar a usar Kadu&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>ConfigWizardConfigurationUiHandler</name>
    <message>
        <source>Start Configuration Wizard</source>
        <translation>Iniciar el Asistente de Configuración</translation>
    </message>
</context>
<context>
    <name>ConfigWizardProfilePage</name>
    <message>
        <source>&lt;h3&gt;Welcome to Kadu Instant Messenger&lt;/h3&gt;&lt;p&gt;This wizard will help you to configure the basic settings of Kadu.&lt;/p&gt;&lt;p&gt;Please choose a preferred language and create a nickname&lt;/p&gt;</source>
        <translation>&lt;h3&gt;Bienvenido a Kadu Instant Messenger&lt;/h3&gt;&lt;p&gt;Este asistente te ayudará a configurar las opciones básicas de Kadu.&lt;/p&gt;&lt;p&gt;Por favor, selecciona un idioma preferido y crea un apodo&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;h3&gt;Profile setup&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Configuración del perfil&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Idioma</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Apodo</translation>
    </message>
</context>
<context>
    <name>ConfigWizardSetUpAccountPage</name>
    <message>
        <source>&lt;h3&gt;Account Setup&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Configuración de la Cuenta&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;Please enter your account data.&lt;/p&gt;&lt;p&gt;Go back if you want to select a different Account Setup option.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Por favor introduce tu información de la cuenta.&lt;/p&gt;&lt;p&gt;Vuelve atrás si quieres seleccionar una opción de Configuración de Cuenta diferente&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>ConfigWizardWindow</name>
    <message>
        <source>Kadu Wizard</source>
        <translation>Asistente Kadu</translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/config_wizard/translations/config_wizard_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Kadu needs to be restarted before changes to the language settings will take effect.</source>
        <translation>Kadu debe reiniciarse antes para que los cambios en la configuración de idioma tengan efecto.</translation>
    </message>
</context>
<context>
    <name>ConfigWizardActions</name>
    <message>
        <source>Start Configuration Wizard</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ConfigWizardChooseNetworkPage</name>
    <message>
        <source>&lt;h3&gt;Account Setup&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Configuración de la Cuenta&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>IM Network</source>
        <translation>Red IM</translation>
    </message>
    <message>
        <source>I want to set up existing account for Kadu</source>
        <translation>Quiero configurar una cuenta existente para Kadu</translation>
    </message>
    <message>
        <source>I want to create new account for Kadu</source>
        <translation>Quiero crear nueva cuenta para Kadu</translation>
    </message>
    <message>
        <source>I don&apos;t want to set up my account for Kadu now</source>
        <translation>No quiero configurar mi cuenta para Kadu ahora</translation>
    </message>
    <message>
        <source>&lt;p&gt;Please choose the network for the account that you would like to set up.&lt;/p&gt;&lt;p&gt;You can also create a new account in the wizard if you don&apos;t already have one&lt;/p&gt;</source>
        <translation>&lt;p&gt;Por favor, elige la red para la cuenta que deseas configurar.&lt;/p&gt;&lt;p&gt;También puedes crear una cuenta nueva en el asistente si todavía no tienes una&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>ConfigWizardCompletedPage</name>
    <message>
        <source>&lt;h3&gt;Configuration Wizard Completed&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Asistente de Configuración Completado&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>Go to Accounts Setting after closing this window</source>
        <translation>Ir a la Configuración de las Cuentas después de cerrar esta ventana</translation>
    </message>
    <message>
        <source>&lt;p&gt;Confirm your wizard setting to start using Kadu.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Confirma tu configuración del asistente para empezar a usar Kadu&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>ConfigWizardProfilePage</name>
    <message>
        <source>&lt;h3&gt;Welcome to Kadu Instant Messenger&lt;/h3&gt;&lt;p&gt;This wizard will help you to configure the basic settings of Kadu.&lt;/p&gt;&lt;p&gt;Please choose a preferred language and create a nickname&lt;/p&gt;</source>
        <translation>&lt;h3&gt;Bienvenido a Kadu Instant Messenger&lt;/h3&gt;&lt;p&gt;Este asistente te ayudará a configurar las opciones básicas de Kadu.&lt;/p&gt;&lt;p&gt;Por favor, selecciona un idioma preferido y crea un apodo&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;h3&gt;Profile setup&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Configuración del perfil&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Idioma</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Apodo</translation>
    </message>
</context>
<context>
    <name>ConfigWizardSetUpAccountPage</name>
    <message>
        <source>&lt;h3&gt;Account Setup&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Configuración de la Cuenta&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;Please enter your account data.&lt;/p&gt;&lt;p&gt;Go back if you want to select a different Account Setup option.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Por favor introduce tu información de la cuenta.&lt;/p&gt;&lt;p&gt;Vuelve atrás si quieres seleccionar una opción de Configuración de Cuenta diferente&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>ConfigWizardWindow</name>
    <message>
        <source>Kadu Wizard</source>
        <translation>Asistente Kadu</translation>
    </message>
</context>
</TS>
